## Credits

# Original author:
Val Kneeman under the name [django-menuware](https://github.com/un33k/django-menuware)

# Development Lead:
* Milton Lenis - miltonln04@gmail.com

# Contributors:
None yet. Why not be the first?
